@@ -18,7 +18,7 @@ build_time_vars = {'ABIFLAGS': '',
  'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'sparc64-unknown-openbsd7.2',
+ 'BUILD_GNU_TYPE': 'sparc64-unknown-openbsd7.3',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
@@ -37,8 +37,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--enable-shared' '--with-fpectl' '--with-threads' "
-                "'--enable-ipv6' '--with-system-expat' '--with-system-ffi' "
+ 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' '--with-fpectl' "
+                "'--with-threads' '--enable-ipv6' '--with-system-expat' "
+                "'--with-system-ffi' "
                 "'--with-tcltk-includes=-I/usr/local/include/tcl8.6 "
                 "-I/usr/local/include/tk8.6 -I/usr/X11R6/include' "
                 "'--with-tcltk-libs=-L/usr/X11R6/lib -ltcl86 -ltk86' "
@@ -51,8 +52,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/tmp/pobj/Python-3.10.9/Python-3.10.9/coverage.info',
- 'COVERAGE_REPORT': '/build/tmp/pobj/Python-3.10.9/Python-3.10.9/lcov-report',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-3.10.10/Python-3.10.10/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.10.10/Python-3.10.10/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
@@ -80,7 +81,7 @@ build_time_vars = {'ABIFLAGS': '',
  'DTRACE_OBJS': '',
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
- 'ENSUREPIP': 'upgrade',
+ 'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
  'EXPERIMENTAL_ISOLATED_SUBINTERPRETERS': 0,
@@ -515,7 +516,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_VFORK': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
- 'HAVE_WAITID': 0,
+ 'HAVE_WAITID': 1,
  'HAVE_WAITPID': 1,
  'HAVE_WCHAR_H': 1,
  'HAVE_WCSCOLL': 1,
@@ -526,17 +527,17 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'sparc64-unknown-openbsd7.2',
+ 'HOST_GNU_TYPE': 'sparc64-unknown-openbsd7.3',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.10 '
                    '/usr/local/include/python3.10',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.10',
- 'INSTALL': '/build/tmp/pobj//Python-3.10.9/bin/install -c',
- 'INSTALL_DATA': '/build/tmp/pobj//Python-3.10.9/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/build/tmp/pobj//Python-3.10.9/bin/install -c -s -m 755',
- 'INSTALL_SCRIPT': '/build/tmp/pobj//Python-3.10.9/bin/install -c -m 755',
- 'INSTALL_SHARED': '/build/tmp/pobj//Python-3.10.9/bin/install -c -m 755',
+ 'INSTALL': '/usr/obj/ports/Python-3.10.10/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-3.10.10/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.10.10/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.10.10/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-3.10.10/bin/install -c -m 755',
  'INSTSONAME': 'libpython3.10.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
@@ -669,13 +670,13 @@ build_time_vars = {'ABIFLAGS': '',
                    '-I/usr/local/include -I./Include/internal -I. -I./Include '
                    '-I/usr/local/include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/usr/local/lib/ '
-                    '-L/build/tmp/pobj//Python-3.10.9/Python-3.10.9 '
+                    '-L/usr/obj/ports/Python-3.10.10/Python-3.10.10 '
                     '-L/usr/local/lib/',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-L/usr/local/lib/',
- 'PY_LDFLAGS_NODIST': '-L/build/tmp/pobj//Python-3.10.9/Python-3.10.9 '
+ 'PY_LDFLAGS_NODIST': '-L/usr/obj/ports/Python-3.10.10/Python-3.10.10 '
                       '-L/usr/local/lib/',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
@@ -695,7 +696,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.10.9/Python-3.10.9',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.10.10/Python-3.10.10',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SHELL': '/bin/sh',
@@ -738,10 +739,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '-L/usr/X11R6/lib -ltcl86 -ltk86',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.10.9/Python-3.10.9 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.10.10/Python-3.10.10 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.10.9/Python-3.10.9 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.10.10/Python-3.10.10 '
                './python ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -769,8 +770,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/tmp/pobj/Python-3.10.9/Python-3.10.9',
- 'abs_srcdir': '/build/tmp/pobj/Python-3.10.9/Python-3.10.9',
+ 'abs_builddir': '/usr/obj/ports/Python-3.10.10/Python-3.10.10',
+ 'abs_srcdir': '/usr/obj/ports/Python-3.10.10/Python-3.10.10',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
